@@ -2,7 +2,7 @@
     Parse INI files.
 
 """
-from __future__ import print_function, absolute_import
+from __future__ import absolute_import
 
 import io
 import re
